about summary refs log tree commit diff
path: root/support
diff options
context:
space:
mode:
authorH.J. Lu <hjl.tools@gmail.com>2021-07-09 14:17:04 -0700
committerH.J. Lu <hjl.tools@gmail.com>2021-07-09 15:20:55 -0700
commit28d07380c2ae5786e242be336ccc1c9e3111f3fa (patch)
tree0ba709c5fab2fbcde01d9e34c939e200fbd25b4b /support
parent5d98a7dae955bafa6740c26eaba9c86060ae0344 (diff)
downloadglibc-28d07380c2ae5786e242be336ccc1c9e3111f3fa.tar.gz
glibc-28d07380c2ae5786e242be336ccc1c9e3111f3fa.tar.xz
glibc-28d07380c2ae5786e242be336ccc1c9e3111f3fa.zip
support: Replace MINSIGSTKSZ with sysconf (_SC_MINSIGSTKSZ)
Replace MINSIGSTKSZ with sysconf (_SC_MINSIGSTKSZ) since the constant
MINSIGSTKSZ used in glibc build may be too small.

Reviewed-by: Carlos O'Donell <carlos@redhat.com>
Diffstat (limited to 'support')
-rw-r--r--support/support_stack_alloc.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/support/support_stack_alloc.c b/support/support_stack_alloc.c
index 03494dd185..b05ae08968 100644
--- a/support/support_stack_alloc.c
+++ b/support/support_stack_alloc.c
@@ -39,10 +39,11 @@ support_stack_alloc (size_t size)
   if (pagesize == -1)
     FAIL_EXIT1 ("sysconf (_SC_PAGESIZE): %m\n");
 
-  /* Always supply at least MINSIGSTKSZ space; passing 0 as size means
-     only that much space.  No matter what the number is, round it up
-     to a whole number of pages.  */
-  size_t stacksize = roundup (size + MINSIGSTKSZ, pagesize);
+  /* Always supply at least sysconf (_SC_MINSIGSTKSZ) space; passing 0
+     as size means only that much space.  No matter what the number is,
+     round it up to a whole number of pages.  */
+  size_t stacksize = roundup (size + sysconf (_SC_MINSIGSTKSZ),
+			      pagesize);
 
   /* The guard bands need to be large enough to intercept offset
      accesses from a stack address that might otherwise hit another